Certificate class

The SSL certificate that can be used to encrypt connections between the endpoints and the replication instance.

Constructors

Certificate({String? certificateArn, DateTime? certificateCreationDate, String? certificateIdentifier, String? certificateOwner, String? certificatePem, Uint8List? certificateWallet, int? keyLength, String? signingAlgorithm, DateTime? validFromDate, DateTime? validToDate})
Certificate.fromJson(Map<String, dynamic> json)
factory

Properties

certificateArn → String?
The Amazon Resource Name (ARN) for the certificate.
final
certificateCreationDate → DateTime?
The date that the certificate was created.
final
certificateIdentifier → String?
A customer-assigned name for the certificate. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
final
certificateOwner → String?
The owner of the certificate.
final
certificatePem → String?
The contents of a .pem file, which contains an X.509 certificate.
final
certificateWallet → Uint8List?
The location of an imported Oracle Wallet certificate for use with SSL.
final
hashCode → int
The hash code for this object.
no setterinherited
keyLength → int?
The key length of the cryptographic algorithm being used.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingAlgorithm → String?
The signing algorithm for the certificate.
final
validFromDate → DateTime?
The beginning date that the certificate is valid.
final
validToDate → DateTime?
The final date that the certificate is valid.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited