Connection class

Status of the connection between an endpoint and a replication instance, including Amazon Resource Names (ARNs) and the last error message issued.

Constructors

Connection({String? endpointArn, String? endpointIdentifier, String? lastFailureMessage, String? replicationInstanceArn, String? replicationInstanceIdentifier, String? status})
Connection.fromJson(Map<String, dynamic> json)
factory

Properties

endpointArn → String?
The ARN string that uniquely identifies the endpoint.
final
endpointIdentifier → String?
The identifier of the endpoint. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
final
hashCode → int
The hash code for this object.
no setterinherited
lastFailureMessage → String?
The error message when the connection last failed.
final
replicationInstanceArn → String?
The ARN of the replication instance.
final
replicationInstanceIdentifier → String?
The replication instance identifier. This parameter is stored as a lowercase string.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The connection status. This parameter can return one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited