DescribeEventsResponse class

Constructors

DescribeEventsResponse({List<Event>? events, String? marker})
DescribeEventsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

events → List<Event>?
The events described.
final
hashCode → int
The hash code for this object.
no setterinherited
marker → String?
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited