DescribeReplicationInstanceTaskLogsResponse class

Constructors

DescribeReplicationInstanceTaskLogsResponse({String? marker, String? replicationInstanceArn, List<ReplicationInstanceTaskLog>? replicationInstanceTaskLogs})
DescribeReplicationInstanceTaskLogsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
marker → String?
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
final
replicationInstanceArn → String?
The Amazon Resource Name (ARN) of the replication instance.
final
replicationInstanceTaskLogs → List<ReplicationInstanceTaskLog>?
An array of replication task log metadata. Each member of the array contains the replication task name, ARN, and task log size (in bytes).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited