DescribeReplicationTaskAssessmentRunsResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
marker → String?
A pagination token returned for you to pass to a subsequent request. If you pass this token as the Marker value in a subsequent request, the response includes only records beyond the marker, up to the value specified in the request by MaxRecords.
final
replicationTaskAssessmentRuns → List<ReplicationTaskAssessmentRun>?
One or more premigration assessment runs as specified by Filters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited