DescribeTableStatisticsResponse class

Constructors

DescribeTableStatisticsResponse({String? marker, String? replicationTaskArn, List<TableStatistics>? tableStatistics})
DescribeTableStatisticsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
marker → String?
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
final
replicationTaskArn → String?
The Amazon Resource Name (ARN) of the replication task.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableStatistics → List<TableStatistics>?
The table statistics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited