ElasticsearchSettings class

Provides information that defines an Elasticsearch endpoint.

Constructors

ElasticsearchSettings({required String endpointUri, required String serviceAccessRoleArn, int? errorRetryDuration, int? fullLoadErrorPercentage})
ElasticsearchSettings.fromJson(Map<String, dynamic> json)
factory

Properties

endpointUri → String
The endpoint for the Elasticsearch cluster. AWS DMS uses HTTPS if a transport protocol (http/https) is not specified.
final
errorRetryDuration → int?
The maximum number of seconds for which DMS retries failed API requests to the Elasticsearch cluster.
final
fullLoadErrorPercentage → int?
The maximum percentage of records that can fail to be written before a full load operation stops.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccessRoleArn → String
The Amazon Resource Name (ARN) used by service to access the IAM role.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited