Endpoint class

Describes an endpoint of a database instance in response to operations such as the following:

  • CreateEndpoint
  • DescribeEndpoint
  • DescribeEndpointTypes
  • ModifyEndpoint

Constructors

Endpoint({String? certificateArn, String? databaseName, DmsTransferSettings? dmsTransferSettings, DocDbSettings? docDbSettings, DynamoDbSettings? dynamoDbSettings, ElasticsearchSettings? elasticsearchSettings, String? endpointArn, String? endpointIdentifier, ReplicationEndpointTypeValue? endpointType, String? engineDisplayName, String? engineName, String? externalId, String? externalTableDefinition, String? extraConnectionAttributes, IBMDb2Settings? iBMDb2Settings, KafkaSettings? kafkaSettings, KinesisSettings? kinesisSettings, String? kmsKeyId, MicrosoftSQLServerSettings? microsoftSQLServerSettings, MongoDbSettings? mongoDbSettings, MySQLSettings? mySQLSettings, NeptuneSettings? neptuneSettings, OracleSettings? oracleSettings, int? port, PostgreSQLSettings? postgreSQLSettings, RedshiftSettings? redshiftSettings, S3Settings? s3Settings, String? serverName, String? serviceAccessRoleArn, DmsSslModeValue? sslMode, String? status, SybaseSettings? sybaseSettings, String? username})
Endpoint.fromJson(Map<String, dynamic> json)
factory

Properties

certificateArn → String?
The Amazon Resource Name (ARN) used for SSL connection to the endpoint.
final
databaseName → String?
The name of the database at the endpoint.
final
dmsTransferSettings → DmsTransferSettings?
The settings in JSON format for the DMS transfer type of source endpoint.
final
docDbSettings → DocDbSettings?
final
dynamoDbSettings → DynamoDbSettings?
The settings for the DynamoDB target endpoint. For more information, see the DynamoDBSettings structure.
final
elasticsearchSettings → ElasticsearchSettings?
The settings for the Elasticsearch source endpoint. For more information, see the ElasticsearchSettings structure.
final
endpointArn → String?
The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
final
endpointIdentifier → String?
The database endpoint identifier. Identifiers must begin with a letter and must contain only ASCII letters, digits, and hyphens. They can't end with a hyphen or contain two consecutive hyphens.
final
endpointType → ReplicationEndpointTypeValue?
The type of endpoint. Valid values are source and target.
final
engineDisplayName → String?
The expanded name for the engine name. For example, if the EngineName parameter is "aurora," this value would be "Amazon Aurora MySQL."
final
engineName → String?
The database engine name. Valid values, depending on the EndpointType, include "mysql", "oracle", "postgres", "mariadb", "aurora", "aurora-postgresql", "redshift", "s3", "db2", "azuredb", "sybase", "dynamodb", "mongodb", "kinesis", "kafka", "elasticsearch", "documentdb", "sqlserver", and "neptune".
final
externalId → String?
Value returned by a call to CreateEndpoint that can be used for cross-account validation. Use it on a subsequent call to CreateEndpoint to create the endpoint with a cross-account.
final
externalTableDefinition → String?
The external table definition.
final
extraConnectionAttributes → String?
Additional connection attributes used to connect to the endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
iBMDb2Settings → IBMDb2Settings?
The settings for the IBM Db2 LUW source endpoint. For more information, see the IBMDb2Settings structure.
final
kafkaSettings → KafkaSettings?
The settings for the Apache Kafka target endpoint. For more information, see the KafkaSettings structure.
final
kinesisSettings → KinesisSettings?
The settings for the Amazon Kinesis target endpoint. For more information, see the KinesisSettings structure.
final
kmsKeyId → String?
An AWS KMS key identifier that is used to encrypt the connection parameters for the endpoint.
final
microsoftSQLServerSettings → MicrosoftSQLServerSettings?
The settings for the Microsoft SQL Server source and target endpoint. For more information, see the MicrosoftSQLServerSettings structure.
final
mongoDbSettings → MongoDbSettings?
The settings for the MongoDB source endpoint. For more information, see the MongoDbSettings structure.
final
mySQLSettings → MySQLSettings?
The settings for the MySQL source and target endpoint. For more information, see the MySQLSettings structure.
final
neptuneSettings → NeptuneSettings?
The settings for the Amazon Neptune target endpoint. For more information, see the NeptuneSettings structure.
final
oracleSettings → OracleSettings?
The settings for the Oracle source and target endpoint. For more information, see the OracleSettings structure.
final
port → int?
The port value used to access the endpoint.
final
postgreSQLSettings → PostgreSQLSettings?
The settings for the PostgreSQL source and target endpoint. For more information, see the PostgreSQLSettings structure.
final
redshiftSettings → RedshiftSettings?
Settings for the Amazon Redshift endpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3Settings → S3Settings?
The settings for the S3 target endpoint. For more information, see the S3Settings structure.
final
serverName → String?
The name of the server at the endpoint.
final
serviceAccessRoleArn → String?
The Amazon Resource Name (ARN) used by the service access IAM role.
final
sslMode → DmsSslModeValue?
The SSL mode used to connect to the endpoint. The default value is none.
final
status → String?
The status of the endpoint.
final
sybaseSettings → SybaseSettings?
The settings for the SAP ASE source and target endpoint. For more information, see the SybaseSettings structure.
final
username → String?
The user name used to connect to the endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited