Event class

Describes an identifiable significant activity that affects a replication instance or task. This object can provide the message, the available event categories, the date and source of the event, and the AWS DMS resource type.

Constructors

Event({DateTime? date, List<String>? eventCategories, String? message, String? sourceIdentifier, SourceType? sourceType})
Event.fromJson(Map<String, dynamic> json)
factory

Properties

date → DateTime?
The date of the event.
final
eventCategories → List<String>?
The event categories available for the specified source type.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The event message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceIdentifier → String?
The identifier of an event source.
final
sourceType → SourceType?
The type of AWS DMS resource that generates events.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited