EventSubscription class

Describes an event notification subscription created by the CreateEventSubscription operation.

Constructors

EventSubscription({String? custSubscriptionId, String? customerAwsId, bool? enabled, List<String>? eventCategoriesList, String? snsTopicArn, List<String>? sourceIdsList, String? sourceType, String? status, String? subscriptionCreationTime})
EventSubscription.fromJson(Map<String, dynamic> json)
factory

Properties

customerAwsId → String?
The AWS customer account associated with the AWS DMS event notification subscription.
final
custSubscriptionId → String?
The AWS DMS event notification subscription Id.
final
enabled → bool?
Boolean value that indicates if the event subscription is enabled.
final
eventCategoriesList → List<String>?
A lists of event categories.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snsTopicArn → String?
The topic ARN of the AWS DMS event notification subscription.
final
sourceIdsList → List<String>?
A list of source Ids for the event subscription.
final
sourceType → String?
The type of AWS DMS resource that generates events.
final
status → String?
The status of the AWS DMS event notification subscription.
final
subscriptionCreationTime → String?
The time the AWS DMS event notification subscription was created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited