Filter class

Identifies the name and value of a filter object. This filter is used to limit the number and type of AWS DMS objects that are returned for a particular Describe* call or similar operation. Filters are used as an optional parameter for certain API operations.

Constructors

Filter({required String name, required List<String> values})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the filter as specified for a Describe* or similar operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values → List<String>
The filter value, which can specify one or more values used to narrow the returned results.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited