IBMDb2Settings class

Provides information that defines an IBM Db2 LUW endpoint.

Constructors

IBMDb2Settings({String? currentLsn, String? databaseName, int? maxKBytesPerRead, String? password, int? port, String? secretsManagerAccessRoleArn, String? secretsManagerSecretId, String? serverName, bool? setDataCaptureChanges, String? username})
IBMDb2Settings.fromJson(Map<String, dynamic> json)
factory

Properties

currentLsn → String?
For ongoing replication (CDC), use CurrentLSN to specify a log sequence number (LSN) where you want the replication to start.
final
databaseName → String?
Database name for the endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
maxKBytesPerRead → int?
Maximum number of bytes per read, as a NUMBER value. The default is 64 KB.
final
password → String?
Endpoint connection password.
final
port → int?
Endpoint TCP port.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretsManagerAccessRoleArn → String?
The full Amazon Resource Name (ARN) of the IAM role that specifies AWS DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. SecretsManagerSecret has the value of the AWS Secrets Manager secret that allows access to the Db2 LUW endpoint.
final
secretsManagerSecretId → String?
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the Db2 LUW endpoint connection details.
final
serverName → String?
Fully qualified domain name of the endpoint.
final
setDataCaptureChanges → bool?
Enables ongoing replication (CDC) as a BOOLEAN value. The default is true.
final
username → String?
Endpoint connection user name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited