MongoDbSettings class

Provides information that defines a MongoDB endpoint.

Constructors

MongoDbSettings({AuthMechanismValue? authMechanism, String? authSource, AuthTypeValue? authType, String? databaseName, String? docsToInvestigate, String? extractDocId, String? kmsKeyId, NestingLevelValue? nestingLevel, String? password, int? port, String? secretsManagerAccessRoleArn, String? secretsManagerSecretId, String? serverName, String? username})
MongoDbSettings.fromJson(Map<String, dynamic> json)
factory

Properties

authMechanism → AuthMechanismValue?
The authentication mechanism you use to access the MongoDB source endpoint.
final
authSource → String?
The MongoDB database name. This setting isn't used when AuthType is set to "no".
final
authType → AuthTypeValue?
The authentication type you use to access the MongoDB source endpoint.
final
databaseName → String?
The database name on the MongoDB source endpoint.
final
docsToInvestigate → String?
Indicates the number of documents to preview to determine the document organization. Use this setting when NestingLevel is set to "one".
final
extractDocId → String?
Specifies the document ID. Use this setting when NestingLevel is set to "none".
final
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyId → String?
The AWS KMS key identifier that is used to encrypt the content on the replication instance. If you don't specify a value for the KmsKeyId parameter, then AWS DMS uses your default encryption key. AWS KMS creates the default encryption key for your AWS account. Your AWS account has a different default encryption key for each AWS Region.
final
nestingLevel → NestingLevelValue?
Specifies either document or table mode.
final
password → String?
The password for the user account you use to access the MongoDB source endpoint.
final
port → int?
The port value for the MongoDB source endpoint.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretsManagerAccessRoleArn → String?
The full Amazon Resource Name (ARN) of the IAM role that specifies AWS DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. SecretsManagerSecret has the value of the AWS Secrets Manager secret that allows access to the MongoDB endpoint.
final
secretsManagerSecretId → String?
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the MongoDB endpoint connection details.
final
serverName → String?
The name of the server on the MongoDB source endpoint.
final
username → String?
The user name you use to access the MongoDB source endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited