MySQLSettings class

Provides information that defines a MySQL endpoint.

Constructors

MySQLSettings({String? afterConnectScript, String? databaseName, int? eventsPollInterval, int? maxFileSize, int? parallelLoadThreads, String? password, int? port, String? secretsManagerAccessRoleArn, String? secretsManagerSecretId, String? serverName, String? serverTimezone, TargetDbType? targetDbType, String? username})
MySQLSettings.fromJson(Map<String, dynamic> json)
factory

Properties

afterConnectScript → String?
Specifies a script to run immediately after AWS DMS connects to the endpoint. The migration task continues running regardless if the SQL statement succeeds or fails.
final
databaseName → String?
Database name for the endpoint.
final
eventsPollInterval → int?
Specifies how often to check the binary log for new changes/events when the database is idle.
final
hashCode → int
The hash code for this object.
no setterinherited
maxFileSize → int?
Specifies the maximum size (in KB) of any .csv file used to transfer data to a MySQL-compatible database.
final
parallelLoadThreads → int?
Improves performance when loading data into the MySQL-compatible target database. Specifies how many threads to use to load the data into the MySQL-compatible target database. Setting a large number of threads can have an adverse effect on database performance, because a separate connection is required for each thread.
final
password → String?
Endpoint connection password.
final
port → int?
Endpoint TCP port.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretsManagerAccessRoleArn → String?
The full Amazon Resource Name (ARN) of the IAM role that specifies AWS DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. SecretsManagerSecret has the value of the AWS Secrets Manager secret that allows access to the MySQL endpoint.
final
secretsManagerSecretId → String?
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the MySQL endpoint connection details.
final
serverName → String?
Fully qualified domain name of the endpoint.
final
serverTimezone → String?
Specifies the time zone for the source MySQL database.
final
targetDbType → TargetDbType?
Specifies where to migrate source tables on the target, either to a single database or multiple databases.
final
username → String?
Endpoint connection user name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited