OrderableReplicationInstance class

In response to the DescribeOrderableReplicationInstances operation, this object describes an available replication instance. This description includes the replication instance's type, engine version, and allocated storage.

Constructors

OrderableReplicationInstance({List<String>? availabilityZones, int? defaultAllocatedStorage, String? engineVersion, int? includedAllocatedStorage, int? maxAllocatedStorage, int? minAllocatedStorage, ReleaseStatusValues? releaseStatus, String? replicationInstanceClass, String? storageType})
OrderableReplicationInstance.fromJson(Map<String, dynamic> json)
factory

Properties

availabilityZones → List<String>?
List of Availability Zones for this replication instance.
final
defaultAllocatedStorage → int?
The default amount of storage (in gigabytes) that is allocated for the replication instance.
final
engineVersion → String?
The version of the replication engine.
final
hashCode → int
The hash code for this object.
no setterinherited
includedAllocatedStorage → int?
The amount of storage (in gigabytes) that is allocated for the replication instance.
final
maxAllocatedStorage → int?
The minimum amount of storage (in gigabytes) that can be allocated for the replication instance.
final
minAllocatedStorage → int?
The minimum amount of storage (in gigabytes) that can be allocated for the replication instance.
final
releaseStatus → ReleaseStatusValues?
The value returned when the specified EngineVersion of the replication instance is in Beta or test mode. This indicates some features might not work as expected.
final
replicationInstanceClass → String?
The compute and memory capacity of the replication instance as defined for the specified replication instance class. For example to specify the instance class dms.c4.large, set this parameter to "dms.c4.large".
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageType → String?
The type of storage used by the replication instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited