failTasksOnLobTruncation property
When set to true, this value causes a task to fail if the
actual size of a LOB column is greater than the specified
LobMaxSize.
If task is set to Limited LOB mode and this option is set to true, the task fails instead of truncating the LOB data.
Implementation
final bool? failTasksOnLobTruncation;