RedshiftSettings class

Provides information that defines an Amazon Redshift endpoint.

Constructors

RedshiftSettings({bool? acceptAnyDate, String? afterConnectScript, String? bucketFolder, String? bucketName, bool? caseSensitiveNames, bool? compUpdate, int? connectionTimeout, String? databaseName, String? dateFormat, bool? emptyAsNull, EncryptionModeValue? encryptionMode, bool? explicitIds, int? fileTransferUploadStreams, int? loadTimeout, int? maxFileSize, String? password, int? port, bool? removeQuotes, String? replaceChars, String? replaceInvalidChars, String? secretsManagerAccessRoleArn, String? secretsManagerSecretId, String? serverName, String? serverSideEncryptionKmsKeyId, String? serviceAccessRoleArn, String? timeFormat, bool? trimBlanks, bool? truncateColumns, String? username, int? writeBufferSize})
RedshiftSettings.fromJson(Map<String, dynamic> json)
factory

Properties

acceptAnyDate → bool?
A value that indicates to allow any date format, including invalid formats such as 00/00/00 00:00:00, to be loaded without generating an error. You can choose true or false (the default).
final
afterConnectScript → String?
Code to run after connecting. This parameter should contain the code itself, not the name of a file containing the code.
final
bucketFolder → String?
An S3 folder where the comma-separated-value (.csv) files are stored before being uploaded to the target Redshift cluster.
final
bucketName → String?
The name of the intermediate S3 bucket used to store .csv files before uploading data to Redshift.
final
caseSensitiveNames → bool?
If Amazon Redshift is configured to support case sensitive schema names, set CaseSensitiveNames to true. The default is false.
final
compUpdate → bool?
If you set CompUpdate to true Amazon Redshift applies automatic compression if the table is empty. This applies even if the table columns already have encodings other than RAW. If you set CompUpdate to false, automatic compression is disabled and existing column encodings aren't changed. The default is true.
final
connectionTimeout → int?
A value that sets the amount of time to wait (in milliseconds) before timing out, beginning from when you initially establish a connection.
final
databaseName → String?
The name of the Amazon Redshift data warehouse (service) that you are working with.
final
dateFormat → String?
The date format that you are using. Valid values are auto (case-sensitive), your date format string enclosed in quotes, or NULL. If this parameter is left unset (NULL), it defaults to a format of 'YYYY-MM-DD'. Using auto recognizes most strings, even some that aren't supported when you use a date format string.
final
emptyAsNull → bool?
A value that specifies whether AWS DMS should migrate empty CHAR and VARCHAR fields as NULL. A value of true sets empty CHAR and VARCHAR fields to null. The default is false.
final
encryptionMode → EncryptionModeValue?
The type of server-side encryption that you want to use for your data. This encryption type is part of the endpoint settings or the extra connections attributes for Amazon S3. You can choose either SSE_S3 (the default) or SSE_KMS. To use SSE_S3, create an AWS Identity and Access Management (IAM) role with a policy that allows "arn:aws:s3:::*" to use the following actions: "s3:PutObject", "s3:ListBucket"
final
explicitIds → bool?
This setting is only valid for a full-load migration task. Set ExplicitIds to true to have tables with IDENTITY columns override their auto-generated values with explicit values loaded from the source data files used to populate the tables. The default is false.
final
fileTransferUploadStreams → int?
The number of threads used to upload a single file. This parameter accepts a value from 1 through 64. It defaults to 10.
final
hashCode → int
The hash code for this object.
no setterinherited
loadTimeout → int?
The amount of time to wait (in milliseconds) before timing out of operations performed by AWS DMS on a Redshift cluster, such as Redshift COPY, INSERT, DELETE, and UPDATE.
final
maxFileSize → int?
The maximum size (in KB) of any .csv file used to load data on an S3 bucket and transfer data to Amazon Redshift. It defaults to 1048576KB (1 GB).
final
password → String?
The password for the user named in the username property.
final
port → int?
The port number for Amazon Redshift. The default value is 5439.
final
removeQuotes → bool?
A value that specifies to remove surrounding quotation marks from strings in the incoming data. All characters within the quotation marks, including delimiters, are retained. Choose true to remove quotation marks. The default is false.
final
replaceChars → String?
A value that specifies to replaces the invalid characters specified in ReplaceInvalidChars, substituting the specified characters instead. The default is "?".
final
replaceInvalidChars → String?
A list of characters that you want to replace. Use with ReplaceChars.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretsManagerAccessRoleArn → String?
The full Amazon Resource Name (ARN) of the IAM role that specifies AWS DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. SecretsManagerSecret has the value of the AWS Secrets Manager secret that allows access to the Amazon Redshift endpoint.
final
secretsManagerSecretId → String?
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the Amazon Redshift endpoint connection details.
final
serverName → String?
The name of the Amazon Redshift cluster you are using.
final
serverSideEncryptionKmsKeyId → String?
The AWS KMS key ID. If you are using SSE_KMS for the EncryptionMode, provide this key ID. The key that you use needs an attached policy that enables IAM user permissions and allows use of the key.
final
serviceAccessRoleArn → String?
The Amazon Resource Name (ARN) of the IAM role that has access to the Amazon Redshift service.
final
timeFormat → String?
The time format that you want to use. Valid values are auto (case-sensitive), 'timeformat_string', 'epochsecs', or 'epochmillisecs'. It defaults to 10. Using auto recognizes most strings, even some that aren't supported when you use a time format string.
final
trimBlanks → bool?
A value that specifies to remove the trailing white space characters from a VARCHAR string. This parameter applies only to columns with a VARCHAR data type. Choose true to remove unneeded white space. The default is false.
final
truncateColumns → bool?
A value that specifies to truncate data in columns to the appropriate number of characters, so that the data fits in the column. This parameter applies only to columns with a VARCHAR or CHAR data type, and rows with a size of 4 MB or less. Choose true to truncate data. The default is false.
final
username → String?
An Amazon Redshift user name for a registered user.
final
writeBufferSize → int?
The size (in KB) of the in-memory file write buffer used when generating .csv files on the local disk at the DMS replication instance. The default value is 1000 (buffer size is 1000KB).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited