RefreshSchemasStatus class

Provides information that describes status of a schema at an endpoint specified by the DescribeRefreshSchemaStatus operation.

Constructors

RefreshSchemasStatus({String? endpointArn, String? lastFailureMessage, DateTime? lastRefreshDate, String? replicationInstanceArn, RefreshSchemasStatusTypeValue? status})
RefreshSchemasStatus.fromJson(Map<String, dynamic> json)
factory

Properties

endpointArn → String?
The Amazon Resource Name (ARN) string that uniquely identifies the endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
lastFailureMessage → String?
The last failure message for the schema.
final
lastRefreshDate → DateTime?
The date the schema was last refreshed.
final
replicationInstanceArn → String?
The Amazon Resource Name (ARN) of the replication instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → RefreshSchemasStatusTypeValue?
The status of the schema.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited