ReplicationInstance class

Provides information that defines a replication instance.

Constructors

ReplicationInstance({int? allocatedStorage, bool? autoMinorVersionUpgrade, String? availabilityZone, String? dnsNameServers, String? engineVersion, DateTime? freeUntil, DateTime? instanceCreateTime, String? kmsKeyId, bool? multiAZ, ReplicationPendingModifiedValues? pendingModifiedValues, String? preferredMaintenanceWindow, bool? publiclyAccessible, String? replicationInstanceArn, String? replicationInstanceClass, String? replicationInstanceIdentifier, String? replicationInstancePrivateIpAddress, List<String>? replicationInstancePrivateIpAddresses, String? replicationInstancePublicIpAddress, List<String>? replicationInstancePublicIpAddresses, String? replicationInstanceStatus, ReplicationSubnetGroup? replicationSubnetGroup, String? secondaryAvailabilityZone, List<VpcSecurityGroupMembership>? vpcSecurityGroups})
ReplicationInstance.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedStorage → int?
The amount of storage (in gigabytes) that is allocated for the replication instance.
final
autoMinorVersionUpgrade → bool?
Boolean value indicating if minor version upgrades will be automatically applied to the instance.
final
availabilityZone → String?
The Availability Zone for the instance.
final
dnsNameServers → String?
The DNS name servers supported for the replication instance to access your on-premise source or target database.
final
engineVersion → String?
The engine version number of the replication instance.
final
freeUntil → DateTime?
The expiration date of the free replication instance that is part of the Free DMS program.
final
hashCode → int
The hash code for this object.
no setterinherited
instanceCreateTime → DateTime?
The time the replication instance was created.
final
kmsKeyId → String?
An AWS KMS key identifier that is used to encrypt the data on the replication instance.
final
multiAZ → bool?
Specifies whether the replication instance is a Multi-AZ deployment. You can't set the AvailabilityZone parameter if the Multi-AZ parameter is set to true.
final
pendingModifiedValues → ReplicationPendingModifiedValues?
The pending modification values.
final
preferredMaintenanceWindow → String?
The maintenance window times for the replication instance. Any pending upgrades to the replication instance are performed during this time.
final
publiclyAccessible → bool?
Specifies the accessibility options for the replication instance. A value of true represents an instance with a public IP address. A value of false represents an instance with a private IP address. The default value is true.
final
replicationInstanceArn → String?
The Amazon Resource Name (ARN) of the replication instance.
final
replicationInstanceClass → String?
The compute and memory capacity of the replication instance as defined for the specified replication instance class. It is a required parameter, although a defualt value is pre-selected in the DMS console.
final
replicationInstanceIdentifier → String?
The replication instance identifier is a required parameter. This parameter is stored as a lowercase string.
final
replicationInstancePrivateIpAddress → String?
The private IP address of the replication instance.
final
replicationInstancePrivateIpAddresses → List<String>?
One or more private IP addresses for the replication instance.
final
replicationInstancePublicIpAddress → String?
The public IP address of the replication instance.
final
replicationInstancePublicIpAddresses → List<String>?
One or more public IP addresses for the replication instance.
final
replicationInstanceStatus → String?
The status of the replication instance. The possible return values include:
final
replicationSubnetGroup → ReplicationSubnetGroup?
The subnet group for the replication instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryAvailabilityZone → String?
The Availability Zone of the standby replication instance in a Multi-AZ deployment.
final
vpcSecurityGroups → List<VpcSecurityGroupMembership>?
The VPC security group for the instance.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited