ReplicationInstanceTaskLog class

Contains metadata for a replication instance task log.

Constructors

ReplicationInstanceTaskLog({int? replicationInstanceTaskLogSize, String? replicationTaskArn, String? replicationTaskName})
ReplicationInstanceTaskLog.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
replicationInstanceTaskLogSize → int?
The size, in bytes, of the replication task log.
final
replicationTaskArn → String?
The Amazon Resource Name (ARN) of the replication task.
final
replicationTaskName → String?
The name of the replication task.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited