ReplicationPendingModifiedValues class

Provides information about the values of pending modifications to a replication instance. This data type is an object of the ReplicationInstance user-defined data type.

Constructors

ReplicationPendingModifiedValues({int? allocatedStorage, String? engineVersion, bool? multiAZ, String? replicationInstanceClass})
ReplicationPendingModifiedValues.fromJson(Map<String, dynamic> json)
factory

Properties

allocatedStorage → int?
The amount of storage (in gigabytes) that is allocated for the replication instance.
final
engineVersion → String?
The engine version number of the replication instance.
final
hashCode → int
The hash code for this object.
no setterinherited
multiAZ → bool?
Specifies whether the replication instance is a Multi-AZ deployment. You can't set the AvailabilityZone parameter if the Multi-AZ parameter is set to true.
final
replicationInstanceClass → String?
The compute and memory capacity of the replication instance as defined for the specified replication instance class.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited