ReplicationTask class

Provides information that describes a replication task created by the CreateReplicationTask operation.

Constructors

ReplicationTask({String? cdcStartPosition, String? cdcStopPosition, String? lastFailureMessage, MigrationTypeValue? migrationType, String? recoveryCheckpoint, String? replicationInstanceArn, String? replicationTaskArn, DateTime? replicationTaskCreationDate, String? replicationTaskIdentifier, String? replicationTaskSettings, DateTime? replicationTaskStartDate, ReplicationTaskStats? replicationTaskStats, String? sourceEndpointArn, String? status, String? stopReason, String? tableMappings, String? targetEndpointArn, String? targetReplicationInstanceArn, String? taskData})
ReplicationTask.fromJson(Map<String, dynamic> json)
factory

Properties

cdcStartPosition → String?
Indicates when you want a change data capture (CDC) operation to start. Use either CdcStartPosition or CdcStartTime to specify when you want the CDC operation to start. Specifying both values results in an error.
final
cdcStopPosition → String?
Indicates when you want a change data capture (CDC) operation to stop. The value can be either server time or commit time.
final
hashCode → int
The hash code for this object.
no setterinherited
lastFailureMessage → String?
The last error (failure) message generated for the replication task.
final
migrationType → MigrationTypeValue?
The type of migration.
final
recoveryCheckpoint → String?
Indicates the last checkpoint that occurred during a change data capture (CDC) operation. You can provide this value to the CdcStartPosition parameter to start a CDC operation that begins at that checkpoint.
final
replicationInstanceArn → String?
The ARN of the replication instance.
final
replicationTaskArn → String?
The Amazon Resource Name (ARN) of the replication task.
final
replicationTaskCreationDate → DateTime?
The date the replication task was created.
final
replicationTaskIdentifier → String?
The user-assigned replication task identifier or name.
final
replicationTaskSettings → String?
The settings for the replication task.
final
replicationTaskStartDate → DateTime?
The date the replication task is scheduled to start.
final
replicationTaskStats → ReplicationTaskStats?
The statistics for the task, including elapsed time, tables loaded, and table errors.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceEndpointArn → String?
The Amazon Resource Name (ARN) that uniquely identifies the endpoint.
final
status → String?
The status of the replication task. This response parameter can return one of the following values:
final
stopReason → String?
The reason the replication task was stopped. This response parameter can return one of the following values:
final
tableMappings → String?
Table mappings specified in the task.
final
targetEndpointArn → String?
The ARN that uniquely identifies the endpoint.
final
targetReplicationInstanceArn → String?
The ARN of the replication instance to which this task is moved in response to running the MoveReplicationTask operation. Otherwise, this response parameter isn't a member of the ReplicationTask object.
final
taskData → String?
Supplemental information that the task requires to migrate the data for certain source and target endpoints. For more information, see Specifying Supplemental Data for Task Settings in the AWS Database Migration Service User Guide.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited