ReplicationTaskAssessmentResult class

The task assessment report in JSON format.

Constructors

ReplicationTaskAssessmentResult({String? assessmentResults, String? assessmentResultsFile, String? assessmentStatus, String? replicationTaskArn, String? replicationTaskIdentifier, DateTime? replicationTaskLastAssessmentDate, String? s3ObjectUrl})
ReplicationTaskAssessmentResult.fromJson(Map<String, dynamic> json)
factory

Properties

assessmentResults → String?
The task assessment results in JSON format.
final
assessmentResultsFile → String?
The file containing the results of the task assessment.
final
assessmentStatus → String?
The status of the task assessment.
final
hashCode → int
The hash code for this object.
no setterinherited
replicationTaskArn → String?
The Amazon Resource Name (ARN) of the replication task.
final
replicationTaskIdentifier → String?
The replication task identifier of the task on which the task assessment was run.
final
replicationTaskLastAssessmentDate → DateTime?
The date the task assessment was completed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3ObjectUrl → String?
The URL of the S3 object containing the task assessment results.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited