ReplicationTaskAssessmentRun class

Provides information that describes a premigration assessment run that you have started using the StartReplicationTaskAssessmentRun operation.

Some of the information appears based on other operations that can return the ReplicationTaskAssessmentRun object.

Constructors

ReplicationTaskAssessmentRun({ReplicationTaskAssessmentRunProgress? assessmentProgress, String? assessmentRunName, String? lastFailureMessage, String? replicationTaskArn, String? replicationTaskAssessmentRunArn, DateTime? replicationTaskAssessmentRunCreationDate, String? resultEncryptionMode, String? resultKmsKeyArn, String? resultLocationBucket, String? resultLocationFolder, String? serviceAccessRoleArn, String? status})
ReplicationTaskAssessmentRun.fromJson(Map<String, dynamic> json)
factory

Properties

assessmentProgress → ReplicationTaskAssessmentRunProgress?
Indication of the completion progress for the individual assessments specified to run.
final
assessmentRunName → String?
Unique name of the assessment run.
final
hashCode → int
The hash code for this object.
no setterinherited
lastFailureMessage → String?
Last message generated by an individual assessment failure.
final
replicationTaskArn → String?
ARN of the migration task associated with this premigration assessment run.
final
replicationTaskAssessmentRunArn → String?
Amazon Resource Name (ARN) of this assessment run.
final
replicationTaskAssessmentRunCreationDate → DateTime?
Date on which the assessment run was created using the StartReplicationTaskAssessmentRun operation.
final
resultEncryptionMode → String?
Encryption mode used to encrypt the assessment run results.
final
resultKmsKeyArn → String?
ARN of the AWS KMS encryption key used to encrypt the assessment run results.
final
resultLocationBucket → String?
Amazon S3 bucket where AWS DMS stores the results of this assessment run.
final
resultLocationFolder → String?
Folder in an Amazon S3 bucket where AWS DMS stores the results of this assessment run.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccessRoleArn → String?
ARN of the service role used to start the assessment run using the StartReplicationTaskAssessmentRun operation.
final
status → String?
Assessment run status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited