ReplicationTaskAssessmentRunProgress class

The progress values reported by the AssessmentProgress response element.

Constructors

ReplicationTaskAssessmentRunProgress({int? individualAssessmentCompletedCount, int? individualAssessmentCount})
ReplicationTaskAssessmentRunProgress.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
individualAssessmentCompletedCount → int?
The number of individual assessments that have completed, successfully or not.
final
individualAssessmentCount → int?
The number of individual assessments that are specified to run.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited