ReplicationTaskIndividualAssessment class

Provides information that describes an individual assessment from a premigration assessment run.

Constructors

ReplicationTaskIndividualAssessment({String? individualAssessmentName, String? replicationTaskAssessmentRunArn, String? replicationTaskIndividualAssessmentArn, DateTime? replicationTaskIndividualAssessmentStartDate, String? status})
ReplicationTaskIndividualAssessment.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
individualAssessmentName → String?
Name of this individual assessment.
final
replicationTaskAssessmentRunArn → String?
ARN of the premigration assessment run that is created to run this individual assessment.
final
replicationTaskIndividualAssessmentArn → String?
Amazon Resource Name (ARN) of this individual assessment.
final
replicationTaskIndividualAssessmentStartDate → DateTime?
Date when this individual assessment was started as part of running the StartReplicationTaskAssessmentRun operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
Individual assessment status.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited