ReplicationTaskStats class

In response to a request by the DescribeReplicationTasks operation, this object provides a collection of statistics about a replication task.

Constructors

ReplicationTaskStats({int? elapsedTimeMillis, DateTime? freshStartDate, DateTime? fullLoadFinishDate, int? fullLoadProgressPercent, DateTime? fullLoadStartDate, DateTime? startDate, DateTime? stopDate, int? tablesErrored, int? tablesLoaded, int? tablesLoading, int? tablesQueued})
ReplicationTaskStats.fromJson(Map<String, dynamic> json)
factory

Properties

elapsedTimeMillis → int?
The elapsed time of the task, in milliseconds.
final
freshStartDate → DateTime?
The date the replication task was started either with a fresh start or a target reload.
final
fullLoadFinishDate → DateTime?
The date the replication task full load was completed.
final
fullLoadProgressPercent → int?
The percent complete for the full load migration task.
final
fullLoadStartDate → DateTime?
The date the replication task full load was started.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → DateTime?
The date the replication task was started either with a fresh start or a resume. For more information, see StartReplicationTaskType.
final
stopDate → DateTime?
The date the replication task was stopped.
final
tablesErrored → int?
The number of errors that have occurred during this task.
final
tablesLoaded → int?
The number of tables loaded for this task.
final
tablesLoading → int?
The number of tables currently loading for this task.
final
tablesQueued → int?
The number of tables queued for this task.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited