parquetVersion property
The version of the Apache Parquet format that you want to use:
parquet_1_0 (the default) or parquet_2_0.
Implementation
final ParquetVersionValue? parquetVersion;
The version of the Apache Parquet format that you want to use:
parquet_1_0 (the default) or parquet_2_0.
final ParquetVersionValue? parquetVersion;