SupportedEndpointType class

Provides information about types of supported endpoints in response to a request by the DescribeEndpointTypes operation. This information includes the type of endpoint, the database engine name, and whether change data capture (CDC) is supported.

Constructors

SupportedEndpointType({ReplicationEndpointTypeValue? endpointType, String? engineDisplayName, String? engineName, String? replicationInstanceEngineMinimumVersion, bool? supportsCDC})
SupportedEndpointType.fromJson(Map<String, dynamic> json)
factory

Properties

endpointType → ReplicationEndpointTypeValue?
The type of endpoint. Valid values are source and target.
final
engineDisplayName → String?
The expanded name for the engine name. For example, if the EngineName parameter is "aurora," this value would be "Amazon Aurora MySQL."
final
engineName → String?
The database engine name. Valid values, depending on the EndpointType, include "mysql", "oracle", "postgres", "mariadb", "aurora", "aurora-postgresql", "redshift", "s3", "db2", "azuredb", "sybase", "dynamodb", "mongodb", "kinesis", "kafka", "elasticsearch", "documentdb", "sqlserver", and "neptune".
final
hashCode → int
The hash code for this object.
no setterinherited
replicationInstanceEngineMinimumVersion → String?
The earliest AWS DMS engine version that supports this endpoint engine. Note that endpoint engines released with AWS DMS versions earlier than 3.1.1 do not return a value for this parameter.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsCDC → bool?
Indicates if Change Data Capture (CDC) is supported.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited