SybaseSettings class

Provides information that defines a SAP ASE endpoint.

Constructors

SybaseSettings({String? databaseName, String? password, int? port, String? secretsManagerAccessRoleArn, String? secretsManagerSecretId, String? serverName, String? username})
SybaseSettings.fromJson(Map<String, dynamic> json)
factory

Properties

databaseName → String?
Database name for the endpoint.
final
hashCode → int
The hash code for this object.
no setterinherited
password → String?
Endpoint connection password.
final
port → int?
Endpoint TCP port.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretsManagerAccessRoleArn → String?
The full Amazon Resource Name (ARN) of the IAM role that specifies AWS DMS as the trusted entity and grants the required permissions to access the value in SecretsManagerSecret. SecretsManagerSecret has the value of the AWS Secrets Manager secret that allows access to the SAP ASE endpoint.
final
secretsManagerSecretId → String?
The full ARN, partial ARN, or friendly name of the SecretsManagerSecret that contains the SAP SAE endpoint connection details.
final
serverName → String?
Fully qualified domain name of the endpoint.
final
username → String?
Endpoint connection user name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited