TableStatistics class

Provides a collection of table statistics in response to a request by the DescribeTableStatistics operation.

Constructors

TableStatistics({int? ddls, int? deletes, int? fullLoadCondtnlChkFailedRows, DateTime? fullLoadEndTime, int? fullLoadErrorRows, bool? fullLoadReloaded, int? fullLoadRows, DateTime? fullLoadStartTime, int? inserts, DateTime? lastUpdateTime, String? schemaName, String? tableName, String? tableState, int? updates, int? validationFailedRecords, int? validationPendingRecords, String? validationState, String? validationStateDetails, int? validationSuspendedRecords})
TableStatistics.fromJson(Map<String, dynamic> json)
factory

Properties

ddls → int?
The data definition language (DDL) used to build and modify the structure of your tables.
final
deletes → int?
The number of delete actions performed on a table.
final
fullLoadCondtnlChkFailedRows → int?
The number of rows that failed conditional checks during the full load operation (valid only for migrations where DynamoDB is the target).
final
fullLoadEndTime → DateTime?
The time when the full load operation completed.
final
fullLoadErrorRows → int?
The number of rows that failed to load during the full load operation (valid only for migrations where DynamoDB is the target).
final
fullLoadReloaded → bool?
A value that indicates if the table was reloaded (true) or loaded as part of a new full load operation (false).
final
fullLoadRows → int?
The number of rows added during the full load operation.
final
fullLoadStartTime → DateTime?
The time when the full load operation started.
final
hashCode → int
The hash code for this object.
no setterinherited
inserts → int?
The number of insert actions performed on a table.
final
lastUpdateTime → DateTime?
The last time a table was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaName → String?
The schema name.
final
tableName → String?
The name of the table.
final
tableState → String?
The state of the tables described.
final
updates → int?
The number of update actions performed on a table.
final
validationFailedRecords → int?
The number of records that failed validation.
final
validationPendingRecords → int?
The number of records that have yet to be validated.
final
validationState → String?
The validation state of the table.
final
validationStateDetails → String?
Additional details about the state of validation.
final
validationSuspendedRecords → int?
The number of records that couldn't be validated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited