TableToReload class

Provides the name of the schema and table to be reloaded.

Constructors

TableToReload({required String schemaName, required String tableName})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaName → String
The schema name of the table to be reloaded.
final
tableName → String
The table name of the table to be reloaded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited