VpcSecurityGroupMembership class

Describes the status of a security group associated with the virtual private cloud (VPC) hosting your replication and DB instances.

Constructors

VpcSecurityGroupMembership({String? status, String? vpcSecurityGroupId})
VpcSecurityGroupMembership.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
The status of the VPC security group.
final
vpcSecurityGroupId → String?
The VPC security group ID.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited